=== modified file 'plugin/pbms/src/defs_ms.h'
--- plugin/pbms/src/defs_ms.h	2010-10-18 21:21:20 +0000
+++ plugin/pbms/src/defs_ms.h	2010-11-07 05:11:55 +0000
@@ -146,6 +146,7 @@
 #define MYSQL_PLUGIN_VAR_HEADER				DRIZZLE_PLUGIN_VAR_HEADER
 #define MYSQL_SYSVAR_STR					DRIZZLE_SYSVAR_STR
 #define MYSQL_SYSVAR_INT					DRIZZLE_SYSVAR_INT
+#define MYSQL_SYSVAR_UINT					DRIZZLE_SYSVAR_UINT
 #define MYSQL_SYSVAR						DRIZZLE_SYSVAR
 #define MYSQL_SYSVAR_ULONG					DRIZZLE_SYSVAR_ULONG
 #define MYSQL_SYSVAR_ULONGLONG				DRIZZLE_SYSVAR_ULONGLONG

=== modified file 'plugin/pbms/src/parameters_ms.cc'
--- plugin/pbms/src/parameters_ms.cc	2010-10-18 21:21:20 +0000
+++ plugin/pbms/src/parameters_ms.cc	2010-11-07 05:11:55 +0000
@@ -64,7 +64,7 @@
 #endif
 
 
-static int my_port_number = PBMS_PORT;
+uint32_t pbms_port_number = PBMS_PORT;
 
 static char		*my_repository_threshold = NULL;
 static char		*my_temp_log_threshold = NULL;
@@ -123,7 +123,7 @@
 #endif
 
 //--------------
-uint32_t PBMSParameters::getPortNumber(){ return my_port_number;}
+uint32_t PBMSParameters::getPortNumber(){ return pbms_port_number;}
 
 //--------------
 uint32_t PBMSParameters::getServerID(){ return my_server_id;}
@@ -487,8 +487,8 @@
 
 //-----------------
 //-----------------
-static MYSQL_SYSVAR_INT(port, my_port_number,
-	PLUGIN_VAR_OPCMDARG | PLUGIN_VAR_READONLY,
+static MYSQL_SYSVAR_UINT(port, pbms_port_number,
+	PLUGIN_VAR_READONLY,
 	"The port for the server stream-based communications.",
 	NULL, NULL, PBMS_PORT, 0, 64*1024, 1);
 

=== modified file 'plugin/pbms/src/plugin_ms.cc'
--- plugin/pbms/src/plugin_ms.cc	2010-10-02 21:15:42 +0000
+++ plugin/pbms/src/plugin_ms.cc	2010-11-07 05:11:55 +0000
@@ -28,8 +28,11 @@
 #include <drizzled/common.h>
 #include <drizzled/plugin.h>
 #include <drizzled/session.h>
+#include <boost/program_options.hpp>
+#include <drizzled/module/option_map.h>
 using namespace drizzled;
 using namespace drizzled::plugin;
+namespace po= boost::program_options;
 
 #include "cslib/CSConfig.h"
 #else
@@ -45,7 +48,7 @@
 
 
 #include "defs_ms.h"
-
+#include "pbmslib.h"
 
 /////////////////////////
 // Plugin Definition:
@@ -58,17 +61,37 @@
 extern int pbms_init_func(module::Context &registry);
 extern struct drizzled::drizzle_sys_var* pbms_system_variables[];
 
-static int my_init(module::Context &registry)
+extern uint32_t pbms_port_number;
+
+static void init_options(drizzled::module::option_context &context)
+{
+  context("port",
+          po::value<uint32_t>(&pbms_port_number)->default_value(DEFAULT_PBMS_PORT),
+          N_("Port number to use for connection or 0 for default PBMS port "));
+}
+
+
+static int my_init(module::Context &context)
 {
 	int rtc;
-	
+        const module::option_map &vm= context.getOptions();
+
+        if (vm.count("port"))
+        {
+          if (pbms_port_number > 65535)
+          {
+            errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid port number\n"));
+            return(-1);
+          }
+        }
+
 	PBMSParameters::startUp();
-	rtc = pbms_init_func(registry);
+	rtc = pbms_init_func(context);
 	if (rtc == 0) {
 		pbms_events = new PBMSEvents();
-		registry.add(pbms_events);
+		context.add(pbms_events);
 	}
-	
+
 	return rtc;
 }
 
@@ -82,7 +105,7 @@
 	PLUGIN_LICENSE_GPL,
 	my_init, /* Plugin Init */
 	pbms_system_variables,          /* system variables                */
-	NULL                                            /* config options                  */
+	init_options                                            /* config options                  */
 }
 DRIZZLE_DECLARE_PLUGIN_END;
 

=== added directory 'plugin/pbms/tests'
=== added directory 'plugin/pbms/tests/r'
=== added file 'plugin/pbms/tests/r/basic.result'
--- plugin/pbms/tests/r/basic.result	1970-01-01 00:00:00 +0000
+++ plugin/pbms/tests/r/basic.result	2010-11-07 05:22:17 +0000
@@ -0,0 +1,6 @@
+CREATE TABLE t1 (a int primary key auto_increment, b blob);
+insert into t1 (b) values ("Hello World");
+SELECT COUNT(*) FROM t1;
+COUNT(*)
+1
+drop table t1;

=== added file 'plugin/pbms/tests/r/bug616466_auto_increment_crash.result'
--- plugin/pbms/tests/r/bug616466_auto_increment_crash.result	1970-01-01 00:00:00 +0000
+++ plugin/pbms/tests/r/bug616466_auto_increment_crash.result	2010-11-07 04:44:43 +0000
@@ -0,0 +1,5 @@
+create table autoincbug (id int not null primary key auto_increment, test varchar(10));
+alter table autoincbug auto_increment = 1000;
+insert into autoincbug values (null, 'hej');
+alter table autoincbug auto_increment = 32727;
+drop table autoincbug;

=== added directory 'plugin/pbms/tests/t'
=== added file 'plugin/pbms/tests/t/basic.test'
--- plugin/pbms/tests/t/basic.test	1970-01-01 00:00:00 +0000
+++ plugin/pbms/tests/t/basic.test	2010-11-07 05:22:17 +0000
@@ -0,0 +1,4 @@
+CREATE TABLE t1 (a int primary key auto_increment, b blob);
+insert into t1 (b) values ("Hello World");
+SELECT COUNT(*) FROM t1;
+drop table t1;

=== added file 'plugin/pbms/tests/t/bug616466_auto_increment_crash.test'
--- plugin/pbms/tests/t/bug616466_auto_increment_crash.test	1970-01-01 00:00:00 +0000
+++ plugin/pbms/tests/t/bug616466_auto_increment_crash.test	2010-11-07 04:44:43 +0000
@@ -0,0 +1,5 @@
+create table autoincbug (id int not null primary key auto_increment, test varchar(10));
+alter table autoincbug auto_increment = 1000;
+insert into autoincbug values (null, 'hej');
+alter table autoincbug auto_increment = 32727;
+drop table autoincbug;

=== added file 'plugin/pbms/tests/t/master.opt'
--- plugin/pbms/tests/t/master.opt	1970-01-01 00:00:00 +0000
+++ plugin/pbms/tests/t/master.opt	2010-11-07 05:11:55 +0000
@@ -0,0 +1,1 @@
+--plugin-add=pbms --pbms.port=$PBMS_PORT

=== modified file 'po/POTFILES.in'
--- po/POTFILES.in	2010-10-28 15:43:26 +0000
+++ po/POTFILES.in	2010-11-07 06:50:21 +0000
@@ -84,6 +84,7 @@
 plugin/mysql_protocol/mysql_protocol.cc
 plugin/mysql_unix_socket_protocol/protocol.cc
 plugin/pbms/src/parameters_ms.cc
+plugin/pbms/src/plugin_ms.cc
 plugin/rabbitmq/rabbitmq_log.cc
 plugin/session_dictionary/processlist.cc
 plugin/signal_handler/signal_handler.cc

=== modified file 'tests/test-run.pl'
--- tests/test-run.pl	2010-10-08 21:27:53 +0000
+++ tests/test-run.pl	2010-11-07 05:10:46 +0000
@@ -212,6 +212,7 @@
 our $opt_master_myport;
 our $opt_slave_myport;
 our $opt_memc_myport;
+our $opt_pbms_myport;
 our $opt_record;
 my $opt_report_features;
 our $opt_check_testcases;
@@ -489,6 +490,7 @@
              'master_port=i'            => \$opt_master_myport,
              'slave_port=i'             => \$opt_slave_myport,
              'memc_port=i'              => \$opt_memc_myport,
+	     'pbms_port=i'              => \$opt_pbms_myport,
 	     'dtr-build-thread=i'       => \$opt_dtr_build_thread,
 
              # Test case authoring
@@ -1132,6 +1134,7 @@
 
   $opt_slave_myport=          gimme_a_good_port($opt_master_myport + 2);  # and 3 4
   $opt_memc_myport= gimme_a_good_port($opt_master_myport + 10);
+  $opt_pbms_myport= gimme_a_good_port($opt_master_myport + 11);
 
   if ( $opt_master_myport < 5001 or $opt_master_myport + 10 >= 32767 )
   {
@@ -1454,6 +1457,7 @@
   $ENV{'SLAVE_MYPORT1'}=      $slave->[1]->{'port'};
   $ENV{'SLAVE_MYPORT2'}=      $slave->[2]->{'port'};
   $ENV{'MC_PORT'}=            $opt_memc_myport;
+  $ENV{'PBMS_PORT'}=            $opt_pbms_myport;
   $ENV{'DRIZZLE_TCP_PORT'}=     $drizzled_variables{'drizzle-protocol.port'};
 
   $ENV{'DTR_BUILD_THREAD'}=      $opt_dtr_build_thread;
@@ -1609,6 +1613,7 @@
     print "Using SLAVE_MYPORT1         = $ENV{SLAVE_MYPORT1}\n";
     print "Using SLAVE_MYPORT2         = $ENV{SLAVE_MYPORT2}\n";
     print "Using MC_PORT               = $ENV{MC_PORT}\n";
+    print "Using PBMS_PORT             = $ENV{PBMS_PORT}\n";
   }
 
   # Create an environment variable to make it possible

